@@ -32,8 +32,31 @@ class SiliconFlow(API):
             'Kwai-Kolors/Kolors'
         ]
 
-    def __init__(self, api_key: str, model: str):
+    def __init__(self, api_key: str):
         super().__init__(api_key, 'https://api.siliconflow.cn')
-        self.model = model
-    def pre_request(self, headers: dict, data: dict):
-        super().pre_request(headers, data)
\ No newline at end of file
+        self.options['timeout'] = 50
+
+    def chat(self, *user_prompt: str, **kwargs):
+        kwargs['model'] = self.model
+        return super().chat(*user_prompt, **kwargs)
+
+    def encode(self, *_input: str) -> list[list[float]]:
+        json = {
+            'input': _input,
+            'model': self.model
+        }
+        response = self.request(f"{self.base_url}/embeddings", "POST", json=json)
+        return [_['embedding'] for _ in response['data']]
+
+    def which(self, query: str, documents: list[str], **kwargs)->tuple[str,int]:
+        json = {
+            'model': self.model,
+            'query': query,
+            'documents': documents,
+            **kwargs
+        }
+        response = self.request(f"{self.base_url}/rerank", "POST", json=json)
+        most_relevant_index = max(response['results'], key=lambda x: x['relevance_score'])['index']
+
+        return documents[most_relevant_index], most_relevant_index
+
