@@ -1,5 +1,5 @@
 from abc import ABC
-from typing import Optional, List
+from typing import Optional
 
 
 class AbstractClient(ABC):
@@ -16,10 +16,10 @@ class AbstractClient(ABC):
     def as_embeddings(self, model: str):
         self.model = model
 
-    def chat(self, user_prompt: str, **kwargs):
+    def chat(self, *user_prompt, **kwargs):
         ...
 
-    def encode(self, *_input: str) -> List[List[float]]:
+    def encode(self, *_input: str) -> list[list[float]]:
         ...
     def connect(self):
         ...
